#' Render fairify reports
#'
#' `render_reports` renders all reports in the specified `report_dir` folder.
#'
#' `render_report` renders one report specified by its folder.
#'
#' `render_report_setup` prepare the report for rendering. This function should be
#' called in the first chunk of the report in order to make the templates available
#' for rendering.
#'
#' @inheritParams list_reports
#' @param publish_dir [character] rendering output path (root folder of the reports)
#' @param output_format output format, see [bookdown::render_book]. Only
#' `"bookdown::gitbook"` and `"bookdown::pdf_book"` are currently handled
#' @param clean_cache [logical] clean Rmarkdown cache files
#' @param ... Parameters passed to [render_report] and [bookdown::render_book]
#'
#' @return `NULL`, this function is used for side effect.
#' @export
#' @rdname render_reports
#'
#' @example man-examples/render_reports.R
#'
render_reports <- function(reports_dir = file.path(pkgload::pkg_path(), "reports"),
                           reports = list.dirs(reports_dir, full.names = FALSE, recursive = FALSE),
                           publish_dir = file.path(dirname(reports_dir), "public/reports"),
                           ...) {
  message("folder list:")
  invisible(sapply(reports, message))

  for (report in reports){
    message("\n*******************************************************************")
    message("** RENDER ", report)
    message("*******************************************************************")
    render_report(input = file.path(reports_dir, report),
                  output_dir = file.path(publish_dir, report),
                  ...)
  }
  invisible()
}
